@@ -1,4 +1,4 @@
 library(drfit)
 data(IM1xVibrio)
 rIM1xVibrio <- drfit(IM1xVibrio)
-rIM1xVibrio
+print(rIM1xVibrio,digits=5)
